@@ -9,9 +9,9 @@ example_data <- data.frame(
 
 p <- plot_usmap("counties", fill = "red")
 q <- plot_usmap(data = statepop, values = "pop_2015", color = "blue")
-r <- plot_usmap(data = example_data, size = 0.8)
+r <- plot_usmap(data = example_data, linewidth = 0.8)
 s <- plot_usmap(include = c("AL", "FL", "GA"), labels = TRUE, label_color = "blue")
-t <- plot_usmap("county", include = "AZ", labels = TRUE, fill = "yellow", size = 0.6)
+t <- plot_usmap("county", include = "AZ", labels = TRUE, fill = "yellow", linewidth = 0.6)
 u <- plot_usmap(include = .new_england, exclude = "ME", labels = TRUE)
 v <- plot_usmap("state", labels = TRUE)
 
@@ -65,23 +65,23 @@ test_that("layer parameters are correct", {
   expect_equal(deparse(p$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(p$layers[[1]]$aes_params$colour), "black")
   expect_equal(as.character(p$layers[[1]]$aes_params$fill), "red")
-  expect_equal(p$layers[[1]]$aes_params$size, 0.4)
+  expect_equal(p$layers[[1]]$aes_params$linewidth, 0.4)
 
   expect_is(q$layers[[1]], "ggproto")
-  expect_equal(deparse(q$layers[[1]]$mapping$x), "~x")
-  expect_equal(deparse(q$layers[[1]]$mapping$y), "~y")
-  expect_equal(deparse(q$layers[[1]]$mapping$group), "~group")
-  expect_equal(deparse(q$layers[[1]]$mapping$fill), "~pop_2015")
+  expect_equal(deparse(q$layers[[1]]$mapping$x), "~.data[[\"x\"]]")
+  expect_equal(deparse(q$layers[[1]]$mapping$y), "~.data[[\"y\"]]")
+  expect_equal(deparse(q$layers[[1]]$mapping$group), "~.data[[\"group\"]]")
+  expect_equal(deparse(q$layers[[1]]$mapping$fill), "~.data[[\"pop_2015\"]]")
   expect_equal(as.character(q$layers[[1]]$aes_params$colour), "blue")
-  expect_equal(q$layers[[1]]$aes_params$size, 0.4)
+  expect_equal(q$layers[[1]]$aes_params$linewidth, 0.4)
 
   expect_is(r$layers[[1]], "ggproto")
-  expect_equal(deparse(r$layers[[1]]$mapping$x), "~x")
-  expect_equal(deparse(r$layers[[1]]$mapping$y), "~y")
-  expect_equal(deparse(r$layers[[1]]$mapping$group), "~group")
-  expect_equal(deparse(r$layers[[1]]$mapping$fill), "~values")
+  expect_equal(deparse(r$layers[[1]]$mapping$x), "~.data[[\"x\"]]")
+  expect_equal(deparse(r$layers[[1]]$mapping$y), "~.data[[\"y\"]]")
+  expect_equal(deparse(r$layers[[1]]$mapping$group), "~.data[[\"group\"]]")
+  expect_equal(deparse(r$layers[[1]]$mapping$fill), "~.data[[\"values\"]]")
   expect_equal(as.character(r$layers[[1]]$aes_params$colour), "black")
-  expect_equal(r$layers[[1]]$aes_params$size, 0.8)
+  expect_equal(r$layers[[1]]$aes_params$linewidth, 0.8)
 
   expect_is(s$layers[[1]], "ggproto")
   expect_equal(deparse(s$layers[[1]]$mapping$x), "~x")
@@ -89,7 +89,7 @@ test_that("layer parameters are correct", {
   expect_equal(deparse(s$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(s$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(s$layers[[1]]$aes_params$colour), "black")
-  expect_equal(s$layers[[1]]$aes_params$size, 0.4)
+  expect_equal(s$layers[[1]]$aes_params$linewidth, 0.4)
   expect_is(s$layers[[2]], "ggproto")
   expect_equal(deparse(s$layers[[2]]$mapping$x), "~x")
   expect_equal(deparse(s$layers[[2]]$mapping$y), "~y")
@@ -102,7 +102,7 @@ test_that("layer parameters are correct", {
   expect_equal(deparse(t$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(t$layers[[1]]$aes_params$fill), "yellow")
   expect_equal(as.character(t$layers[[1]]$aes_params$colour), "black")
-  expect_equal(t$layers[[1]]$aes_params$size, 0.6)
+  expect_equal(t$layers[[1]]$aes_params$linewidth, 0.6)
   expect_is(t$layers[[2]], "ggproto")
   expect_equal(deparse(t$layers[[2]]$mapping$x), "~x")
   expect_equal(deparse(t$layers[[2]]$mapping$y), "~y")
@@ -115,7 +115,7 @@ test_that("layer parameters are correct", {
   expect_equal(deparse(u$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(u$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(u$layers[[1]]$aes_params$colour), "black")
-  expect_equal(u$layers[[1]]$aes_params$size, 0.4)
+  expect_equal(u$layers[[1]]$aes_params$linewidth, 0.4)
   expect_is(u$layers[[2]], "ggproto")
   expect_equal(deparse(u$layers[[2]]$mapping$x), "~x")
   expect_equal(deparse(u$layers[[2]]$mapping$y), "~y")
@@ -127,20 +127,13 @@ test_that("layer parameters are correct", {
   expect_equal(deparse(v$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(v$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(v$layers[[1]]$aes_params$colour), "black")
-  expect_equal(v$layers[[1]]$aes_params$size, 0.4)
+  expect_equal(v$layers[[1]]$aes_params$linewidth, 0.4)
   expect_is(v$layers[[2]], "ggproto")
   expect_equal(deparse(v$layers[[2]]$mapping$x), "~x")
   expect_equal(deparse(v$layers[[2]]$mapping$y), "~y")
   expect_equal(deparse(v$layers[[2]]$mapping$label), "~abbr")
 })
 
-test_that("singular regions can be used", {
-  expect_equal(plot_usmap(regions = "states")$layers,
-               plot_usmap(regions = "state")$layers)
-  expect_equal(plot_usmap(regions = "counties")$layers,
-               plot_usmap(regions = "county")$layers)
-})
-
 test_that("warning occurs for unnecessary fill argument", {
   expect_warning(plot_usmap(data = example_data, fill = "red"))
 })
